# ZenTools for Maya

[![test](https://github.com/enorganic/maya-zen-tools/actions/workflows/test.yml/badge.svg?branch=main)](https://github.com/enorganic/maya-zen-tools/actions/workflows/test.yml)
[![docs](https://github.com/enorganic/maya-zen-tools/actions/workflows/docs.yml/badge.svg?branch=main)](https://github.com/enorganic/maya-zen-tools/actions/workflows/docs.yml)
[![PyPI version](https://badge.fury.io/py/maya-zen-tools.svg?icon=si%3Apython)](https://badge.fury.io/py/maya-zen-tools)

ZenTools for Maya is a set of modeling tools for manipulating a polygon mesh
using dynamically created NURBS curves and surfaces to distribute vertices
and/or UVs, plus some selection tools to complement the workflow.

- [Documentation](https://maya-zen-tools.enorganic.org)
- [Contributing](https://maya-zen-tools.enorganic.org/contributing) (to the development of this package)

![ZenTools for Maya Demo](https://maya-zen-tools.enorganic.org/assets/images/maya-zen-tools-demo.gif)
